<h2>Suggested Cool Links</h2>

[% catid = 0 %]
[% FOREACH item = links %]
    [% IF catid != item.catid %]
        [% IF catid > 0 %]
        </ul>
        [% END %]
        [% catid = item.catid %]
        <h3>[% item.category %]</h3>
        <ul>
        [% catid = item.catid %]
    [% END %]

    [% IF item.title %]
        <li><a href="[% item.href %]" title="link to [% item.title %]">[% item.title %]</a>
    [% ELSE %]
        <li><a href="[% item.href %]" title="link to [% item.href %]">[% item.href %]</a>
    [% END %]

    [% IF item.body %]
        - [% item.body %]
    [% END %]
[% END %]

[% IF catid > 0 %]
</ul>
[% END %]

<p>If you have any link suggestions, or want to report any broken links, please contact
<a href="mailto:barbie@missbarbell.co.uk">Barbie</a>. Please note that any marketing
link swap requests will be ignored, as I already have a high search engine ranking, and
have no desire to help you make money.
