<h2>Category Admin</h2>

<div class="boxer">
[% IF thanks_message %]<p>[% thanks_message %][% END %]
<p>Click on a category title to edit it's content.
<p> <a href="[% cgipath %]/pages.cgi?act=link-cadd">create a new category</a>
|   <a href="[% cgipath %]/pages.cgi?act=link-admin">edit links</a>
</div>

<form name="datalist" method="post" action="[% cgipath %]/pages.cgi">
<input type="hidden" name='act' value='link-cadmin' />

<div class="boxer">
<table class="blocker">
<tr>
    <th>Category</th>
    <th>Order</th>
    <th>Select</th>
</tr>
[% FOREACH item = data %]
<tr>
    <td nowrap><a href="[% cgipath %]/pages.cgi?act=link-cedit&amp;catid=[% item.catid %]">[% item.category %]</a></td>
    <td>[% item.orderno %]</td>
    <td><input type="checkbox" name="LISTED" value="[% item.catid %]" /></td>
</tr>
[% END %]
</table>
</div>

<p>
<input type="submit" name='doaction' value='Delete' />
</form>
